%global uuid    org.%{name}.CoreCtrl

Name:           corectrl
Version:        1.4.3
Release:        %mkrel 2
Summary:        Friendly hardware control
Group:          System/Configuration
# The entire source code is GPLv3+ except bundled libs:
#                   3rdparty/units
# * Public Domain   FindBotan.cmake
License:        GPLv3+ and Boost and BSD and MIT and Public Domain
URL:            https://gitlab.com/corectrl/corectrl
Source0:        https://gitlab.com/corectrl/corectrl/-/archive/v%{version}/%{name}-v%{version}.tar.gz
Source1:        README.mageia.md

BuildRequires:  cmake
BuildRequires:  cmake(Qt5Charts)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(QuaZip-Qt5)
# For experimental stdc++fs, not in shared lib.
BuildRequires:  libstdc++-static-devel
BuildRequires:  pkgconfig(botan-3)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(polkit-gobject-1)
BuildRequires:  pkgconfig(pugixml)
BuildRequires:  pkgconfig(spdlog)
BuildRequires:  pkgconfig(x11)
# for tests
BuildRequires:  cmake(Catch2)
#BuildRequires:  trompeloeil-devel

# * For pidof:
Requires:       procps-ng
# * For pci.ids
Requires:       hwdata

# Used to gather more information
# * For glxinfo
Recommends:     glxinfo

# * For lscpu
Recommends:     util-linux

# * For vulkaninfo
Recommends:     vulkan-tools

# https://gitlab.com/corectrl/corectrl/issues/13
Provides:       bundled(units)

%description
CoreCtrl is a Free and Open Source GNU/Linux application that allows you to
control with ease your computer hardware using application profiles. It aims to
be flexible, comfortable and accessible to regular users.

- For setup instructions run:

  xdg-open %{_docdir}/%{name}/README.mageia.md

- or go to the project wiki:

  https://gitlab.com/corectrl/corectrl/wikis


%prep
%autosetup -n %{name}-v%{version} -p1

# 'lib64' path fix
sed -e 's@DESTINATION lib@DESTINATION %{_lib}@g' -i src/CMakeLists.txt

# lib soversion fix
echo "set_property(TARGET corectrl_lib PROPERTY SOVERSION 0)" >> src/CMakeLists.txt


%build
%cmake -DBUILD_TESTING=OFF
%cmake_build


%install
%cmake_install

install -m 0644 -Dp %{SOURCE1} %{buildroot}%{_docdir}/%{name}/README.mageia.md

# Useless symlink without headers
rm -f %{buildroot}%{_libdir}/libcorectrl.so


%check
#make_build test -C build


%files
%license COPYING LICENSE
%doc README.md README.mageia.md
%{_bindir}/%{name}
%{_datadir}/applications/%{uuid}.desktop
%{_datadir}/dbus-1/system-services/org.%{name}.helper*.service
%{_datadir}/dbus-1/system.d/org.%{name}.helper*.conf
%{_datadir}/icons/hicolor/*/apps/%{name}.svg
%{_datadir}/polkit-1/actions/org.%{name}.helper*.policy
%{_libdir}/lib%{name}.so.0*
%{_libexecdir}/%{name}/%{name}_helper*
%{_metainfodir}/%{uuid}.appdata.xml


%changelog
* Fri Jan 31 2025 daviddavid <daviddavid> 1.4.3-2.mga10
+ Revision: 2143747
- rebuild for new spdlog 1.15.0

* Wed Nov 27 2024 daviddavid <daviddavid> 1.4.3-1.mga10
+ Revision: 2119488
- new version: 1.4.3

* Wed Oct 23 2024 daviddavid <daviddavid> 1.4.2-2.mga10
+ Revision: 2110790
- rebuild for new botan 3.6.0

* Wed Oct 02 2024 daviddavid <daviddavid> 1.4.2-1.mga10
+ Revision: 2102512
- new version: 1.4.2

* Wed Oct 02 2024 daviddavid <daviddavid> 1.4.1-2.mga10
+ Revision: 2102441
- rebuild for new fmt 11.0.2

* Mon Jun 03 2024 daviddavid <daviddavid> 1.4.1-1.mga10
+ Revision: 2069583
- new version: 1.4.1

* Wed May 08 2024 wally <wally> 1.4.0-2.mga10
+ Revision: 2062874
- rebuild for spdlog 1.14.1

* Sun Apr 14 2024 daviddavid <daviddavid> 1.4.0-1.mga10
+ Revision: 2057289
- new version: 1.4.0
- switch to botan-3
- use system pugixml
- bundled easyloggingpp was replaced by system spdlog

* Sat Sep 02 2023 daviddavid <daviddavid> 1.3.1-2.mga10
+ Revision: 1983542
- rebuild for new quazip 1.4

* Tue Nov 22 2022 papoteur <papoteur> 1.3.1-1.mga9
+ Revision: 1909999
- new 1.3.1

* Fri Sep 02 2022 neoclust <neoclust> 1.2.7-1.mga9
+ Revision: 1883541
- New version 1.2.7

* Fri Mar 25 2022 akien <akien> 1.2.3-1.mga9
+ Revision: 1825798
- Version 1.2.3

* Thu Feb 17 2022 akien <akien> 1.2.2-1.mga9
+ Revision: 1779119
- Version 1.2.2

* Mon Jun 21 2021 akien <akien> 1.1.3-1.mga9
+ Revision: 1731499
- Version 1.1.3

* Mon May 03 2021 daviddavid <daviddavid> 1.1.2-1.mga9
+ Revision: 1720973
- new version: 1.1.2

* Sun Apr 18 2021 kekepower <kekepower> 1.1.1-5.mga9
+ Revision: 1716671
- Rebuild for botan 2.18.0

* Wed Dec 16 2020 umeabot <umeabot> 1.1.1-4.mga8
+ Revision: 1658277
- Rebuild for new Qt5

* Sun Nov 08 2020 kekepower <kekepower> 1.1.1-3.mga8
+ Revision: 1643687
- Rebuild for Botan2, major 17

* Sat Oct 31 2020 daviddavid <daviddavid> 1.1.1-2.mga8
+ Revision: 1640785
- rebuild for new botan2 2.16.0

* Sat Oct 17 2020 akien <akien> 1.1.1-1.mga8
+ Revision: 1636582
- Version 1.1.1

* Wed Jul 29 2020 daviddavid <daviddavid> 1.1.0-2.mga8
+ Revision: 1609565
- rebuild for new botan2 2.15.0

* Thu Jun 04 2020 akien <akien> 1.1.0-1.mga8
+ Revision: 1590307
- Adapt packaging to Mageia guidelines
- import corectrl from Fedora Rawhide


* Sun May 31 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 1.1.0-1
- Update to 1.1.0
- Disable LTO

* Mon Apr 20 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 1.0.9-1
- Update to 1.0.9 (basically the same as previous build but now patch upstreamed)

* Mon Mar 16 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 1.0.8-1
- Update to 1.0.8

* Tue Jan 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Sat Nov 23 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 1.0.7-2
- Add new missed BR dep: libdrm-devel

* Sat Nov 23 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 1.0.7-1
- Update to 1.0.7

* Wed Sep 04 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 1.0.6-2
- Remove '$(nproc)' from '-flto' for reproducible builds
- Tiny cosmetic spec file fixes

* Sat Aug 10 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 1.0.6-1
- Update to 1.0.6

* Wed Jul 24 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Tue Jul 23 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 1.0.5-1
- Update to 1.0.5
- App summary more descriptive now (upstream suggestion)

* Wed Jul 17 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 1.0.4-4
- Update to 1.0.4

* Mon Jul 15 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 1.0.3-15
- Initial package
- Thanks to Dead_Mozay <dead_mozay@opensuse.org> for initial spec file
- Thanks to Vitaly Zaitsev <vitaly@easycoding.org> for significant help with packaging and review
